﻿/**
 * Copyright 2008 - TMTDigital LLC
 *
 * Author:   Travis Tidwell (www.travistidwell.com)
 * Version:  1.0
 * Date:     June 9th, 2008
 *
 * Description:  The base class for any given node in the Dash Player.
 *
 **/

package com.tmtdigital.dash.display.node
{
   import com.tmtdigital.dash.display.Skinable;
   import com.tmtdigital.dash.display.Fields;
   import com.tmtdigital.dash.events.DashEvent;
   import com.tmtdigital.dash.net.Service;
   import com.tmtdigital.dash.config.Params;

   import flash.display.*;
   import flash.events.*;
   import flash.geom.*;

   public class NodeBase extends Skinable
   {
      public function NodeBase( _skin:MovieClip )
      {
         super( _skin );
         node = new Object();
      }

      public override function setSkin( _skin:MovieClip )
      {
         super.setSkin( _skin );
         fields = new Fields( skin.fields, type );
      }

      public static function translateNode( _node:* = null ):Object
      {
         var isValue:Boolean = ((_node is Number) || (_node is String)) ? true : false;
         if ( !_node || isValue || (_node.load) ) {
            var nodeId:Number = 0;
            if (_node && ! isValue && _node.load) {
               nodeId = _node.nid;
            }
            else {
               nodeId = _node ? _node:Params.flashVars.node;
            }
            return {nid:nodeId, load:true};
         }
         else {
            _node.load = false;
            return _node;
         }
      }

      public function loadNode( _node:* = null ) : Boolean
      {
         return setNode( translateNode( _node ) );
      }

      public function setNode( _node:Object ):Boolean
      {
         if ( _node.load && _node.nid) {
            Service.call( Service.NODE_LOAD, onNodeLoad, null, String(_node.nid) );
            return true;
         }
         else {
            onNodeLoad( _node );
            return false;
         }

         return false;
      }

      public function onNodeLoad( _node:Object )
      {
         node = _node;

         if (node && fields.skin) {
            fields.loadFields( node );
         }

         dispatchEvent( new DashEvent( DashEvent.NODE_LOADED ) );
      }

      public function preResize()
      {
         if (fields && fields.skin) {
            fields.preResize();
         }
      }

      public function postResize()
      {
         if (fields && fields.skin) {
            fields.postResize();
         }
      }

      public function hideShow()
      {
         if (fields && fields.skin) {
            fields.hideShow();
         }
      }

      public function get loaded():Boolean
      {
         return (node.nid && (node.nid > 0));
      }

      public var node:Object;
      public var fields:Fields;
      public var type:String = "node";
   }
}